@@ -575,9 +575,12 @@ sink_open_cb (GObject *source_object, GAsyncResult *result, gpointer data)
 	GError *error = NULL;
 
 	if (g_task_propagate_boolean (G_TASK (result), &error) == FALSE) {
-		set_error (encoder, error);
+		/* this would have already been done as part of cancel action */
+		if (encoder->priv->cancelled == FALSE) {
+			set_error (encoder, error);
+			rb_encoder_gst_emit_completed (encoder);
+		}
 		g_error_free (error);
-		rb_encoder_gst_emit_completed (encoder);
 	} else {
 		if (encoder->priv->outstream != NULL) {
 			g_object_set (encoder->priv->sink, "stream", encoder->priv->outstream, NULL);
@@ -649,7 +652,6 @@ sink_open (GTask *task, gpointer source_object, gpointer task_data, GCancellable
 				     _("Could not create a temporary file to write to: %s"),
 				    error->message);
 			g_task_return_error (task, error);
-			g_object_unref (task);
 			return;
 		}
 
@@ -708,7 +710,6 @@ sink_open (GTask *task, gpointer source_object, gpointer task_data, GCancellable
 	} else {
 		g_task_return_boolean (task, TRUE);
 	}
-	g_object_unref (task);
 }
 
 static void
@@ -762,6 +763,7 @@ impl_encode (RBEncoder *bencoder,
 
 		task = g_task_new (encoder, encoder->priv->open_cancel, sink_open_cb, NULL);
 		g_task_run_in_thread (task, sink_open);
+		g_object_unref (task);
 	}
 }
 
