@@ -26,7 +26,7 @@
  */
 
 /**
- * SECTION:rb-file-helpers
+ * SECTION:rbfilehelpers
  * @short_description: An assortment of file and URI helper functions
  *
  * This is a variety of functions for dealing with files and URIs, including
@@ -74,7 +74,8 @@ static const char *recurse_attributes =
 		G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
 		G_FILE_ATTRIBUTE_ID_FILE ","
 		G_FILE_ATTRIBUTE_ACCESS_CAN_READ ","
-		G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK;
+		G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
+		G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET;
 
 /**
  * rb_locale_dir:
