@@ -35,7 +35,7 @@
 #include "rb-debug.h"
 
 /**
- * SECTION:rb-ext-db-key
+ * SECTION:rbextdbkey
  * @short_description: key for external metadata lookups
  *
  * An external metadata key consists of one or more required fields (such as
@@ -502,6 +502,31 @@ rb_ext_db_key_field_matches (RBExtDBKey *key, const char *field, const char *val
 	return FALSE;
 }
 
+/**
+ * rb_ext_db_key_is_null_match:
+ * @lookup: lookup key to compare against
+ * @store: store key to compare
+ *
+ * Checks whether @store has a null value in an optional
+ * field of @lookup, which means it's not the most specific
+ * possible match for a query.
+ *
+ * Return value: %TRUE if the storage key has a null value for the lookup key's optional field
+ */
+gboolean
+rb_ext_db_key_is_null_match (RBExtDBKey *lookup, RBExtDBKey *store)
+{
+	GPtrArray *values;
+
+	if (lookup->multi_field == NULL)
+		return FALSE;
+	if (lookup->multi_field->match_null == FALSE)
+		return FALSE;
+
+	values = get_list_values (store->fields, lookup->multi_field->name);
+	return (values == NULL || values->len == 0);
+}
+
 static void
 flatten_store_key (RBExtDBKey *key, TDB_DATA *data)
 {
@@ -532,15 +557,18 @@ create_store_key (RBExtDBKey *key, int option)
 {
 	RBExtDBKey *skey = NULL;
 	GList *l;
+	int nopt;
 
 	g_assert (key->lookup);
-	if (key->multi_field != NULL &&
-	    option > key->multi_field->values->len &&
-	    key->multi_field->match_null == FALSE) {
-		return NULL;
-	} else if (key->multi_field == NULL && option != 0) {
-		return NULL;
+	if (key->multi_field == NULL) {
+		nopt = 1;
+	} else if (key->multi_field->match_null) {
+		nopt = key->multi_field->values->len + 1;
+	} else {
+		nopt = key->multi_field->values->len;
 	}
+	if (option >= nopt)
+		return NULL;
 
 	for (l = key->fields; l != NULL; l = l->next) {
 		RBExtDBField *f = l->data;
