@@ -24,7 +24,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 
-import urllib
+import urllib.parse
 import xml.dom.minidom as dom
 import re
 import configparser
@@ -43,16 +43,16 @@ REPEAT_SEARCH_PERIOD = 86400 * 7
 # this API key belongs to jonathan@d14n.org
 # and was generated specifically for this use
 API_KEY = 'ff56d530598d65c1a4088e57da7be2f9'
-API_URL = 'http://ws.audioscrobbler.com/2.0/'
+API_URL = 'https://ws.audioscrobbler.com/2.0/'
 
 # LASTFM_LOGO = "lastfm_red_small.png"
 # LASTFM_TOOLTIP = (LASTFM_LOGO, _("Image provided by Last.fm"))
 
 DISC_NUMBER_REGEXS = (
-	"\(disc *[0-9]+\)",
-	"\(cd *[0-9]+\)",
-	"\[disc *[0-9]+\]",
-	"\[cd *[0-9]+\]",
+	"\\(disc *[0-9]+\\)",
+	"\\(cd *[0-9]+\\)",
+	"\\[disc *[0-9]+\\]",
+	"\\[cd *[0-9]+\\]",
 	" - disc *[0-9]+$",
 	" - cd *[0-9]+$",
 	" disc *[0-9]+$",
@@ -88,11 +88,11 @@ class LastFMSearch (object):
 		print("searching for (%s, %s, %s)" % (artist, album, album_mbid))
 		url = API_URL + "?method=album.getinfo&"
 		if artist != None:
-			url = url + "artist=%s&" % (urllib.quote_plus(artist))
+			url = url + "artist=%s&" % (urllib.parse.quote_plus(artist))
 		if album != None:
-			url = url + "album=%s&" % (urllib.quote_plus(album))
+			url = url + "album=%s&" % (urllib.parse.quote_plus(album))
 		if album_mbid != None:
-			url = url + "mbid=%s&" % (urllib.quote_plus(album_mbid))
+			url = url + "mbid=%s&" % (urllib.parse.quote_plus(album_mbid))
 
 		url = url + "api_key=%s" % API_KEY
 		print("last.fm query url = %s" % url)
@@ -145,7 +145,7 @@ class LastFMSearch (object):
 		l.get_url(url, self.album_info_cb)
 
 
-	def search(self, key, last_time, store, callback, args):
+	def search(self, key, last_time, store, callback, *args):
 		if last_time > (time.time() - REPEAT_SEARCH_PERIOD):
 			print("we already tried this one")
 			callback (args)
@@ -160,7 +160,7 @@ class LastFMSearch (object):
 		artists = key.get_field_values("artist")
 		album_mbid = key.get_info("musicbrainz-albumid")
 
-		artists = filter(lambda x: x not in (None, "", _("Unknown")), artists)
+		artists = list(filter(lambda x: x not in (None, "", _("Unknown")), artists))
 		if album in ("", _("Unknown")):
 			album = None
 
