@@ -89,10 +89,12 @@ class Magnatune(GObject.GObject, Peas.Activatable):
 		shell = self.object
 		self.db = shell.props.db
 
+		rb.append_plugin_source_path(self, "icons")
+
 		self.entry_type = MagnatuneEntryType()
 		self.db.register_entry_type(self.entry_type)
 
-		self.settings = Gio.Settings("org.gnome.rhythmbox.plugins.magnatune")
+		self.settings = Gio.Settings.new("org.gnome.rhythmbox.plugins.magnatune")
 
 		app = Gio.Application.get_default()
 		action = Gio.SimpleAction(name="magnatune-album-download")
@@ -109,12 +111,11 @@ class Magnatune(GObject.GObject, Peas.Activatable):
 		app.link_shared_menus(toolbar)
 
 		group = RB.DisplayPageGroup.get_by_id ("stores")
-		settings = Gio.Settings("org.gnome.rhythmbox.plugins.magnatune")
-		iconfile = Gio.File.new_for_path(rb.find_plugin_file(self, "magnatune-symbolic.svg"))
+		settings = Gio.Settings.new("org.gnome.rhythmbox.plugins.magnatune")
 		self.source = GObject.new(MagnatuneSource,
 					  shell=shell,
 					  entry_type=self.entry_type,
-					  icon=Gio.FileIcon.new(iconfile),
+					  icon=Gio.ThemedIcon.new("magnatune-symbolic"),
 					  plugin=self,
 					  settings=settings.get_child("source"),
 					  name=_("Magnatune"),
@@ -151,7 +152,7 @@ class MagnatuneConfig(GObject.GObject, PeasGtk.Configurable):
 
 	def __init__(self):
 		GObject.GObject.__init__(self)
-		self.settings = Gio.Settings("org.gnome.rhythmbox.plugins.magnatune")
+		self.settings = Gio.Settings.new("org.gnome.rhythmbox.plugins.magnatune")
 		self.account = MagnatuneAccount.instance()
 
 	def do_create_configure_widget(self):
