@@ -159,6 +159,11 @@ static void download_info_free				(RBPodcastDownload *data);
 static gboolean cancel_download				(RBPodcastDownload *pd);
 static void rb_podcast_manager_start_update_timer 	(RBPodcastManager *pd);
 
+static void podcast_album_art_request_cb		(RBExtDB *db,
+							 RBExtDBKey *key,
+							 guint64 last_time,
+							 RBPodcastManager *pd);
+
 G_DEFINE_TYPE (RBPodcastManager, rb_podcast_manager, G_TYPE_OBJECT)
 
 static void
@@ -276,6 +281,7 @@ rb_podcast_manager_constructed (GObject *object)
 	}
 
 	pd->priv->art_store = rb_ext_db_new ("album-art");
+	g_signal_connect (pd->priv->art_store, "request", G_CALLBACK (podcast_album_art_request_cb), pd);
 
 	pd->priv->soup_session = soup_session_new ();
 	soup_session_set_user_agent (pd->priv->soup_session, PACKAGE "/" VERSION);
@@ -891,10 +897,12 @@ rb_podcast_manager_add_post (RhythmDB *db,
 			     const char *name,
 			     const char *title,
 			     const char *subtitle,
-			     const char *generator,
+			     const char *channel_author,
+			     const char *item_author,
 			     const char *uri,
 			     const char *description,
 			     const char *guid,
+			     const char *img,
 			     gulong date,
 			     gint64 duration,
 			     gulong position,
@@ -963,13 +971,23 @@ rb_podcast_manager_add_post (RhythmDB *db,
 	g_value_unset (&val);
 
 	g_value_init (&val, G_TYPE_STRING);
-	if (generator)
-		g_value_set_string (&val, generator);
+	if (item_author)
+		g_value_set_string (&val, item_author);
+	else if (channel_author)
+		g_value_set_string (&val, channel_author);
 	else
 		g_value_set_static_string (&val, "");
 	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ARTIST, &val);
 	g_value_unset (&val);
 
+	g_value_init (&val, G_TYPE_STRING);
+	if (channel_author)
+		g_value_set_string (&val, channel_author);
+	else
+		g_value_set_static_string (&val, "");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ALBUM_ARTIST, &val);
+	g_value_unset (&val);
+
 	g_value_init (&val, G_TYPE_ULONG);
 	g_get_current_time (&time);
 	if (date == 0)
@@ -990,6 +1008,13 @@ rb_podcast_manager_add_post (RhythmDB *db,
 		g_value_unset (&val);
 	}
 
+	if (img != NULL) {
+		g_value_init (&val, G_TYPE_STRING);
+		g_value_set_string (&val, img);
+		rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_IMAGE, &val);
+		g_value_unset (&val);
+	}
+
 	if (new_entry) {
 		g_value_init (&val, G_TYPE_ULONG);
 		g_value_set_ulong (&val, RHYTHMDB_PODCAST_STATUS_PAUSED);
@@ -1451,8 +1476,7 @@ rb_podcast_manager_add_parsed_feed (RBPodcastManager *pd, RBPodcastChannel *data
 		rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_IMAGE, &val);
 		g_value_unset (&val);
 
-		key = rb_ext_db_key_create_storage ("album", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_TITLE));
-		rb_ext_db_key_add_field (key, "artist", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST));
+		key = rb_ext_db_key_create_storage ("subtitle", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_LOCATION));
 
 		rb_ext_db_store_uri (pd->priv->art_store,
 				     key,
@@ -1529,10 +1553,12 @@ rb_podcast_manager_add_parsed_feed (RBPodcastManager *pd, RBPodcastChannel *data
 			    title,
 			    item->title,
 			    data->url,
-			    (item->author ? item->author : data->author),
+			    data->author,
+			    item->author,
 			    item->url,
 			    item->description,
 			    item->guid,
+			    item->img,
 			    item->pub_date > 0 ? item->pub_date : data->pub_date,
 			    item->duration,
 			    position++,
@@ -1594,8 +1620,17 @@ rb_podcast_manager_add_parsed_feed (RBPodcastManager *pd, RBPodcastChannel *data
 		RhythmDBEntry *entry = l->data;
 
 		if (rb_podcast_manager_entry_downloaded (entry) == FALSE) {
+			RBExtDBKey *key;
+
 			rb_debug ("entry %s is no longer present in the feed and has not been downloaded",
 				  get_remote_location (entry));
+
+			/* delete episode image, if we've downloaded it */
+			key = rb_ext_db_key_create_storage ("subtitle", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_SUBTITLE));
+			rb_ext_db_key_add_field (key, "podcast-guid", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_PODCAST_GUID));
+			rb_ext_db_delete (pd->priv->art_store, key);
+			rb_ext_db_key_free (key);
+
 			rhythmdb_entry_delete (db, entry);
 		} else {
 			/* assign track numbers to remaining entries in the same order */
@@ -2374,6 +2409,47 @@ cancel_download (RBPodcastDownload *data)
 	}
 }
 
+static void
+podcast_album_art_request_cb (RBExtDB *db, RBExtDBKey *key, guint64 last_time, RBPodcastManager *pd)
+{
+	RhythmDBEntry *entry;
+	const char *feed;
+	const char *guid;
+	const char *location;
+	const char *image;
+	const char *feed_image;
+
+	/*
+	 * we only need to answer requests for specific episodes here
+	 * as feed images are stored when the feed is updated
+	 */
+	feed = rb_ext_db_key_get_field (key, "subtitle");
+	guid = rb_ext_db_key_get_field (key, "podcast-guid");
+	location = rb_ext_db_key_get_info (key, "location");
+	if (feed != NULL && guid != NULL && location != NULL) {
+		entry = rhythmdb_entry_lookup_by_location (pd->priv->db, feed);
+		if (entry == NULL)
+			return;
+		feed_image = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_IMAGE);
+
+		entry = rhythmdb_entry_lookup_by_location (pd->priv->db, location);
+		if (entry == NULL)
+			return;
+
+		image = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_IMAGE);
+		if (image != NULL && g_strcmp0 (image, feed_image) != 0) {
+			RBExtDBKey *skey;
+
+			skey = rb_ext_db_key_create_storage ("subtitle", feed);
+			rb_ext_db_key_add_field (skey, "podcast-guid", guid);
+			rb_ext_db_store_uri (db,
+					     skey,
+					     RB_EXT_DB_SOURCE_EMBEDDED, /* sort of */
+					     image);
+		}
+	}
+}
+
 #define ENUM_ENTRY(name, desc) { name, "" #name "", desc }
 
 GType
