@@ -43,7 +43,7 @@
 #include "rb-application.h"
 
 /**
- * SECTION:rb-play-queue-source
+ * SECTION:rbplayqueuesource
  * @short_description: source object for the play queue
  *
  * The main interesting thing about this source is that is
@@ -96,6 +96,7 @@ static void impl_show_entry_view_popup (RBPlaylistSource *source,
 static void impl_save_contents_to_xml (RBPlaylistSource *source,
 				       xmlNodePtr node);
 static gboolean impl_can_remove (RBDisplayPage *page);
+static gboolean impl_check_entry_type (RBSource *source, RhythmDBEntry *entry);
 
 static void queue_clear_action_cb (GSimpleAction *action, GVariant *parameters, gpointer data);
 static void queue_shuffle_action_cb (GSimpleAction *action, GVariant *parameters, gpointer data);
@@ -124,8 +125,8 @@ struct _RBPlayQueueSourcePrivate
 	guint dbus_object_id;
 	GDBusConnection *bus;
 
-	GMenuModel *popup;
-	GMenuModel *sidepane_popup;
+	GMenu *popup;
+	GMenu *sidepane_popup;
 
 	guint update_count_idle_id;
 };
@@ -203,6 +204,7 @@ rb_play_queue_source_class_init (RBPlayQueueSourceClass *klass)
 
 	source_class->can_add_to_queue = (RBSourceFeatureFunc) rb_false_function;
 	source_class->can_rename = (RBSourceFeatureFunc) rb_false_function;
+	source_class->check_entry_type = impl_check_entry_type;
 
 	page_class->can_remove = impl_can_remove;
 
@@ -250,7 +252,7 @@ rb_play_queue_source_constructed (GObject *object)
 	GtkCellRenderer *renderer;
 	GtkBuilder *builder;
 	RhythmDBQueryModel *model;
-	GApplication *app;
+	RBApplication *app;
 	GActionEntry actions[] = {
 		{ "queue-clear", queue_clear_action_cb },
 		{ "queue-shuffle", queue_shuffle_action_cb },
@@ -261,7 +263,7 @@ rb_play_queue_source_constructed (GObject *object)
 
 	RB_CHAIN_GOBJECT_METHOD (rb_play_queue_source_parent_class, constructed, object);
 
-	app = g_application_get_default ();
+	app = RB_APPLICATION (g_application_get_default ());
 	source = RB_PLAY_QUEUE_SOURCE (object);
 	priv = RB_PLAY_QUEUE_SOURCE_GET_PRIVATE (source);
 	db = rb_playlist_source_get_db (RB_PLAYLIST_SOURCE (source));
@@ -280,10 +282,6 @@ rb_play_queue_source_constructed (GObject *object)
 	priv->sidebar = rb_entry_view_new (db, shell_player, TRUE, TRUE);
 	g_object_unref (shell_player);
 
-	g_object_set (priv->sidebar,
-		      "vscrollbar-policy", GTK_POLICY_AUTOMATIC,
-		      "shadow-type", GTK_SHADOW_NONE,
-		      NULL);
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (priv->sidebar)),
 				     "sidebar-queue");
 
@@ -323,10 +321,10 @@ rb_play_queue_source_constructed (GObject *object)
 
 	/* load popup menus */
 	builder = rb_builder_load ("queue-popups.ui", NULL);
-	priv->popup = G_MENU_MODEL (gtk_builder_get_object (builder, "queue-source-popup"));
-	priv->sidepane_popup = G_MENU_MODEL (gtk_builder_get_object (builder, "queue-sidepane-popup"));
-	rb_application_link_shared_menus (RB_APPLICATION (app), G_MENU (priv->popup));
-	rb_application_link_shared_menus (RB_APPLICATION (app), G_MENU (priv->sidepane_popup));
+	priv->popup = G_MENU (gtk_builder_get_object (builder, "queue-source-popup"));
+	priv->sidepane_popup = G_MENU (gtk_builder_get_object (builder, "queue-sidepane-popup"));
+	rb_application_link_shared_menus (app, priv->popup);
+	rb_application_link_shared_menus (app, priv->sidepane_popup);
 	g_object_ref (priv->popup);
 	g_object_ref (priv->sidepane_popup);
 	g_object_unref (builder);
@@ -442,12 +440,19 @@ impl_show_entry_view_popup (RBPlaylistSource *source,
 {
 	RBPlayQueueSourcePrivate *priv = RB_PLAY_QUEUE_SOURCE_GET_PRIVATE (source);
 	GtkWidget *menu;
+	GMenu *popup;
+	RBApplication *app;
 
 	if (view == priv->sidebar) {
-		menu = gtk_menu_new_from_model (priv->sidepane_popup);
+		popup = priv->sidepane_popup;
 	} else {
-		menu = gtk_menu_new_from_model (priv->popup);
+		popup = priv->popup;
 	}
+
+	app = RB_APPLICATION (g_application_get_default ());
+	rb_menu_update_link (popup, "rb-playlist-menu-link", rb_application_get_shared_menu (app, "playlist-page-menu"));
+
+	menu = gtk_menu_new_from_model (G_MENU_MODEL (popup));
 	gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (source), NULL);
 	gtk_menu_popup (GTK_MENU (menu),
 			NULL,
@@ -700,3 +705,9 @@ impl_can_remove (RBDisplayPage *page)
 {
 	return FALSE;
 }
+
+static gboolean
+impl_check_entry_type (RBSource *source, RhythmDBEntry *entry)
+{
+	return (rhythmdb_entry_get_playback_uri (entry) != NULL);
+}
