@@ -80,7 +80,7 @@ G_DEFINE_TYPE (RBCellRendererRating, rb_cell_renderer_rating, GTK_TYPE_CELL_REND
 
 
 /**
- * SECTION:rb-cell-renderer-rating
+ * SECTION:rbcellrendererrating
  * @short_description: a #GtkCellRenderer for displaying song ratings
  *
  * This cell renderer is used to display song ratings in the #RBEntryView,
@@ -214,7 +214,7 @@ rb_cell_renderer_rating_set_property (GObject *object,
  * Return value: the new cell renderer
  **/
 GtkCellRenderer *
-rb_cell_renderer_rating_new ()
+rb_cell_renderer_rating_new (void)
 {
 	return GTK_CELL_RENDERER (g_object_new (rb_cell_renderer_rating_get_type (), NULL, NULL));
 }
